<?php
/**
 * Customizer Theme Function File
 *
 * @package Includes header
 * */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
function advisom_theme_setup() {

	// Make theme available for translation.

	load_theme_textdomain( 'advisom', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	add_theme_support( 'automatic-feed-links' );

	// Let WordPress manage the document title.

	add_theme_support( 'title-tag' );

	// Custom background color.

	add_theme_support( 'custom-background' );

	// Custom Header.

	add_theme_support( 'custom-header' );

	// Enable woocommerce support.

	add_theme_support( 'woocommerce' );

	// Enable support for Post Thumbnails on posts and pages.

	add_theme_support( 'post-thumbnails' );

	add_image_size( 'advisom_post-standard', 1170, 570, true );

	add_image_size( 'advisom_post-widget', 170, 170, true );

	// Register menus.

	register_nav_menu( 'primary', esc_html__( 'Primary Menu', 'advisom' ) );

	register_nav_menu( 'secondary', esc_html__( 'Secondary Menu', 'advisom' ) );

	register_nav_menu( 'onepage', esc_html__( 'Onepage Menu', 'advisom' ) );

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.

	add_theme_support(
		'html5',
		array(

			'search-form',

			'comment-form',

			'comment-list',

			'gallery',

			'caption',

		)
	);

	// Enable support for Post Formats.

	add_theme_support(
		'post-formats',
		array(

		'image',

		'gallery',

		'video'

	) );







	/*



	 * This theme styles the visual editor to resemble the theme style,



	 * specifically font, colors, and column width.



 	 */



	add_editor_style( array( 'assets/css/editor-style.css' ) );



}



add_action( 'after_setup_theme', 'advisom_theme_setup' );







function advisom_elementor_setup() {



	if ( class_exists( '\Elementor\Plugin' ) ) {



		// Color



		$kit = \Elementor\Plugin::$instance->kits_manager->get_active_kit_for_frontend();



		$colors = $kit->get_settings_for_display( 'system_colors' );







		// Primary color : heading



		$colors[0]['color'] = '#1E2228';







		// Text color



		$colors[2]['color'] = '#7E8288';







		// Accent Color



		$colors[3]['color'] = '#000080';







		\Elementor\Plugin::$instance->kits_manager->update_kit_settings_based_on_option( 'system_colors', $colors);







		// Layout



		$layout = $kit->get_settings_for_display( 'container_width' );



		$layout['size'] = '1170';



		\Elementor\Plugin::$instance->kits_manager->update_kit_settings_based_on_option( 'container_width', $layout);



	}



}



add_action( 'after_switch_theme', 'advisom_elementor_setup' );







// Enqueues scripts and styles.



function advisom_theme_scripts() {



	// Vendor Styles & Icons



	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css', array(), '3.5.2' );



	wp_enqueue_style( 'animsition', get_template_directory_uri() . '/assets/css/animsition.css', array(), '4.0.1' );



	wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/css/slick.css', array(), '1.6.0' );



	wp_enqueue_style( 'eleganticons', get_template_directory_uri() . '/assets/css/eleganticons.css', array(), '1.0.0' );



	wp_enqueue_style( 'pe-icon-7-stroke', get_template_directory_uri() . '/assets/css/pe-icon-7-stroke.css', array(), '1.0.0' );



	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/css/fontawesome.css', array(), '5.13.0' );







	// Theme Style



	wp_enqueue_style( 'advisom_theme-style', get_stylesheet_uri(), array(), '1.0.0' );



	wp_add_inline_style( 'advisom_theme-style', apply_filters( 'advisom_custom_colors_css', null ) );







	// Vendor Scripts



	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/assets/js/html5shiv.js', array('jquery'), '3.7.3', true );



	wp_enqueue_script( 'respond', get_template_directory_uri() . '/assets/js/respond.js', array('jquery'), '1.3.0', true );



	wp_enqueue_script( 'matchmedia', get_template_directory_uri() . '/assets/js/matchmedia.js', array('jquery'), '1.0.0', true );



	wp_enqueue_script( 'easing', get_template_directory_uri() . '/assets/js/easing.js', array('jquery'), '1.3.0', true );



	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/assets/js/fitvids.js', array('jquery'), '1.1.0', true );



	wp_enqueue_script( 'animsition', get_template_directory_uri() . '/assets/js/animsition.js', array('jquery'), '4.0.1', true );



	wp_register_script( 'slick', get_template_directory_uri() . '/assets/js/slick.js', array('jquery'), '1.6.0', true );







	// Theme Script



	wp_enqueue_script( 'advisom_theme-script', get_template_directory_uri() . '/assets/js/main.js', array( 'jquery' ), '1.0.0', true );







	// Comment JS



	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )



		wp_enqueue_script( 'comment-reply' );



}



add_action( 'wp_enqueue_scripts', 'advisom_theme_scripts' );







// Registers a widget areas.



function advisom_sidebars_init() {



	// Sidebar for Blog



	register_sidebar( array(



		'name'          => esc_html__( 'Sidebar Blog', 'advisom' ),



		'id'            => 'sidebar-blog',



		'description'   => esc_html__( 'Add widgets here to appear in Sidebar Blog.', 'advisom' ),



		'before_widget' => '<div id="%1$s" class="widget %2$s">',



		'after_widget'  => '</div>',



		'before_title'  => '<h2 class="widget-title"><span>',



		'after_title'   => '</span></h2>'



	) );







	// Sidebar for Pages



	register_sidebar( array(



		'name'			=> esc_html__( 'Sidebar Page', 'advisom' ),



		'id'			=> 'sidebar-page',



		'description'	=> esc_html__( 'Add widgets here to appear in Sidebar Page', 'advisom' ),



		'before_widget'	=> '<div id="%1$s" class="widget %2$s">',



		'after_widget'	=> '</div>',



		'before_title'	=> '<h2 class="widget-title"><span>',



		'after_title'	=> '</span></h2>'



	) );







	// Sidebar for Portfolio



	register_sidebar( array(



		'name'			=> esc_html__( 'Sidebar Portfolio', 'advisom' ),



		'id'			=> 'sidebar-portfolio',



		'description'	=> esc_html__( 'Add widgets here to appear in Sidebar Portfolio', 'advisom' ),



		'before_widget'	=> '<div id="%1$s" class="widget %2$s">',



		'after_widget'	=> '</div>',



		'before_title'	=> '<h2 class="widget-title"><span>',



		'after_title'	=> '</span></h2>'



	) );







	// Sidebar for Shop



	register_sidebar( array(



		'name'			=> esc_html__( 'Sidebar Shop', 'advisom' ),



		'id'			=> 'sidebar-shop',



		'description'	=> esc_html__( 'Add widgets here to appear in Sidebar Shop', 'advisom' ),



		'before_widget'	=> '<div id="%1$s" class="widget %2$s">',



		'after_widget'	=> '</div>',



		'before_title'	=> '<h2 class="widget-title"><span>',



		'after_title'	=> '</span></h2>'



	) );







	// 4 Sidebars for Footer



	register_sidebar( array(



		'name'			=> esc_html__( 'Sidebar Footer 1', 'advisom' ),



		'id'			=> 'sidebar-footer-1',



		'description'	=> esc_html__( 'Add widgets here to appear in Sidebar Footer 1', 'advisom' ),



		'before_widget'	=> '<div id="%1$s" class="widget %2$s">',



		'after_widget'	=> '</div>',



		'before_title'	=> '<h2 class="widget-title"><span>',



		'after_title'	=> '</span></h2>'



	) );



	register_sidebar( array(



		'name'			=> esc_html__( 'Sidebar Footer 2', 'advisom' ),



		'id'			=> 'sidebar-footer-2',



		'description'	=> esc_html__( 'Add widgets here to appear in Sidebar Footer 2', 'advisom' ),



		'before_widget'	=> '<div id="%1$s" class="widget %2$s">',



		'after_widget'	=> '</div>',



		'before_title'	=> '<h2 class="widget-title"><span>',



		'after_title'	=> '</span></h2>'



	) );



	register_sidebar( array(



		'name'			=> esc_html__( 'Sidebar Footer 3', 'advisom' ),



		'id'			=> 'sidebar-footer-3',



		'description'	=> esc_html__( 'Add widgets here to appear in Sidebar Footer 3', 'advisom' ),



		'before_widget'	=> '<div id="%1$s" class="widget %2$s">',



		'after_widget'	=> '</div>',



		'before_title'	=> '<h2 class="widget-title"><span>',



		'after_title'	=> '</span></h2>'



	) );



	register_sidebar( array(



		'name'			=> esc_html__( 'Sidebar Footer 4', 'advisom' ),



		'id'			=> 'sidebar-footer-4',



		'description'	=> esc_html__( 'Add widgets here to appear in Sidebar Footer 4', 'advisom' ),



		'before_widget'	=> '<div id="%1$s" class="widget %2$s">',



		'after_widget'	=> '</div>',



		'before_title'	=> '<h2 class="widget-title"><span>',



		'after_title'	=> '</span></h2>'



	) );



}



add_action( 'widgets_init', 'advisom_sidebars_init' );







// Include required files.



require( get_template_directory() . '/framework/get-mods.php' );



require( get_template_directory() . '/framework/theme-hooks.php' );



require( get_template_directory() . '/framework/theme-functions.php' );



require( get_template_directory() . '/framework/fonts.php' );



require( get_template_directory() . '/framework/typography.php' );



require( get_template_directory() . '/framework/accent-color.php' );



require( get_template_directory() . '/framework/customizer/customizer.php' );



require( get_template_directory() . '/framework/elementor-options.php' );



require( get_template_directory() . '/framework/metabox-options.php' );



require( get_template_directory() . '/framework/widget-areas.php' );



require( get_template_directory() . '/framework/breadcrumbs.php' );



require( get_template_directory() . '/framework/plugins.php' );



require( get_template_directory() . '/framework/theme-woocommerce.php' );



require( get_template_directory() . '/framework/demo-install.php' );





final class ZOOM_Customizer_Reset

{

	private static $instance = null;

	  private $wp_customize;

	public static function get_instance()

	{

		if (null === self::$instance) {

			self::$instance = new self();

		}

		return self::$instance;

	}

	private function __construct()

	{

		add_action('customize_controls_print_scripts', array( $this, 'customize_controls_print_scripts' ));

		add_action('wp_ajax_customizer_reset', array( $this, 'ajax_customizer_reset' ));

		add_action('customize_register', array( $this, 'customize_register' ));

	}



	public function customize_controls_print_scripts()

	{

		wp_enqueue_script('customizer-reset', get_template_directory_uri() . '/assets/js/customizer-reset.js', array( 'jquery' ), '20150120');

		wp_localize_script('customizer-reset', '_ZoomCustomizerReset', array(

		'reset'   => __('Reset', 'advisom'),

		'confirm' => __("Attention! This will remove all customizations ever made via customizer to this theme!\n\nThis action is irreversible!", 'advisom'),

		'nonce'   => array(

			'reset' => wp_create_nonce('customizer-reset'),

		)

		));

	}

	public function customize_register($wp_customize)

	{

		$this->wp_customize = $wp_customize;

	}



	public function ajax_customizer_reset()

	{

		if (! $this->wp_customize->is_preview()) {

			wp_send_json_error('not_preview');

		}



		if (! check_ajax_referer('customizer-reset', 'nonce', false)) {

			wp_send_json_error('invalid_nonce');

		}



		$this->reset_customizer();

		wp_send_json_success();

	}



	public function reset_customizer()

	{

		$settings = $this->wp_customize->settings();

	// remove theme_mod settings registered in customizer

		foreach ($settings as $setting) {

			if ('theme_mod' == $setting->type) {

				remove_theme_mod($setting->id);

			}

		}

	}

}

ZOOM_Customizer_Reset::get_instance();



include get_theme_file_path( 'vendor/autoload.php');
use \WPTRT\Customize\Control\ColorAlpha;

function header_background_add_colorpicker( $wp_customize){

	$wp_customize->add_setting( 'header_background_color' , [
		'default'           => 'rgba(255,255,255,1)', // Use any HEX or RGBA value.
		'transport'         => 'refresh',
		'sanitize_callback' => 'esc_attr',
	] );

	$wp_customize->add_control( new ColorAlpha( $wp_customize, 'header_background_color', [
		'label'      => __( 'Header Background Color', 'advisom' ),
		'section'    => 'advisom_header_site',
		'settings'   => 'header_background_color',
		'priority' => '100',
		'inline_css' => array(
			'target' => '#site-header.fixed-hide',
			'alter' => 'background-color',
		),
	] ) );

}

add_action( 'customize_register', 'header_background_add_colorpicker' );
add_action( 'customize_controls_print_footer_scripts', 'my_customizer_header_script' );
function my_customizer_header_script(){
	?>
	<script type="text/javascript">
	jQuery(document).ready(function ($) {

		/* adv. color option */
		var color_opt = $( '#customize-control-header_background_color' );
		var checked  = $( '#_customize-input-header_fixed' ).prop( "checked" );
		var basic = $( "#_customize-input-header_site_style" ).val();
		/* on page load, hide or show adv. option */
		if( $( '#_customize-input-header_fixed' ).prop( "checked" ) ){
			console.log("SHOW CUSTOM0");
			color_opt.show();
		}
		else{
			color_opt.hide();
		}
		/* on change, hide or show adv. option */
		$( '#_customize-input-header_site_style' ).on('change',function(){
			if( $( '#_customize-input-header_fixed' ).prop( "checked" )==true && $(this).val() == 'style-1' || $(this).val() == 'style-1 header-float' || $(this).val() == 'style-2' || $(this).val() == 'style-3' || $(this).val() == 'style-2 header-float'  || $(this).val() == 'style-4') {
				console.log("SHOW CUSTOM1");
				color_opt.show();
			} else {
				color_opt.hide();
			}
		});

			/* on change, hide or show adv. option */
			$( '#_customize-input-header_fixed' ).on('change',function(){
			if( $( '#_customize-input-header_fixed' ).prop( "checked" )==true) {
				console.log("SHOW CUSTOM2");
				color_opt.show();
			} else {
				color_opt.hide();
			}
		});

	});
	</script>
	<?php
	}
	function background_header_change_basic_css(){

		$header_bgcolor = get_theme_mod('header_background_color');
		if(!empty($header_bgcolor)):
		?>
			<style type="text/css" id="header_background_color">
					#site-header.fixed-hide {
						background-color:<?php echo esc_attr($header_bgcolor); ?>;
					}
					.header-float #site-header{
						background-color:<?php echo esc_attr($header_bgcolor); ?>;
					}
					.header-style-3 .site-header-inner{
						background-color:<?php echo esc_attr($header_bgcolor); ?>;
					}
			</style>
		<?php
		endif;
	}
	add_action( 'wp_head', 'background_header_change_basic_css' );


	function wpdocs_custom_excerpt_length( $length ) {
		return 7;
		}
		add_filter( 'excerpt_length', 'wpdocs_custom_excerpt_length', 999 );




