<?php

/**
 * Header setting for Customizer
 *
 * @package advisom
 * @version 3.6.8
 */

// Exit if accessed directly
if (! defined('ABSPATH')) {
    exit;
}

// Header General
$this->sections['advisom_header_general'] = array(
    'title' => esc_html__('General', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        array(
            'id' => 'header_background',
            'transport' => 'postMessage',
            'control' => array(
                'label' => esc_html__('Background', 'advisom'),
                'type' => 'color',
            ),
            'inline_css' => array(
                'target' => array(
                    '#site-header'
                ),
                'alter' => 'background-color',
            ),
        ),
        array(
            'id' => 'header_padding',
            'transport' => 'postMessage',
            'control' => array(
                'type' => 'text',
                'label' => esc_html__('Padding', 'advisom'),
                'description' => esc_html__('Top Right Bottom Left.', 'advisom'),
            ),
            'inline_css' => array(
                'media_query' => '(min-width: 1199px)',
                'target' => '.site-header-inner',
                'alter' => 'padding',
            ),
            'sanitize_callback' => 'esc_url',
        ),
        array(
            'id' => 'header_class',
            'default' => '',
            'control' => array(
                'label' => esc_html__('Extra Class', 'advisom'),
                'type' => 'text',
                'desc' => esc_html__('Header Class for all pages on website. (e.g. pages, blog posts, single post, archives, etc ). Single page can override this setting in Page Settings metabox when edit.', 'advisom')
            ),
        ),
    )
);

// Header Logo
$this->sections['advisom_header_logo'] = array(
    'title' => esc_html__('Logo', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        array(
            'id' => 'custom_logo',
            'default' => '',
            'control' => array(
                'label' => esc_html__('Logo Image', 'advisom'),
                'type' => 'image',
            ),
        ),
        array(
            'id' => 'logo_width',
            'control' => array(
                'label' => esc_html__('Logo Width', 'advisom'),
                'type' => 'text',
            ),
        ),
    )
);

// Header Menu
$this->sections['advisom_header_menu'] = array(
    'title' => esc_html__('Menu', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        // General
        array(
            'id' => 'menu_show_current',
            'default' => false,
            'control' => array(
                'label' => esc_html__('Show current page indicator?', 'advisom'),
                'type' => 'checkbox',
            ),
        ),
        array(
            'id' => 'menu_link_spacing',
            'transport' => 'postMessage',
            'control' => array(
                'type' => 'text',
                'label' => esc_html__('Link Spacing', 'advisom'),
                'description' => esc_html__('Example: 20px', 'advisom'),
            ),
            'inline_css' => array(
                'target' => array(
                    '#main-nav > ul > li',
                ),
                'alter' => array(
                    'padding-left',
                    'padding-right',
                ),
            ),
        ),
        array(
            'id' => 'menu_height',
            'transport' => 'postMessage',
            'control' => array(
                'type' => 'text',
                'label' => esc_html__('Menu Height', 'advisom'),
                'description' => esc_html__('Example: 100px', 'advisom'),
            ),
            'inline_css' => array(
                'target' => array(
                    '#site-header #main-nav > ul > li > a',
                ),
                'alter' => array(
                    'height',
                    'line-height',
                ),
            ),
        ),
        array(
            'id' => 'menu_link_color',
            'transport' => 'postMessage',
            'control' => array(
                'type' => 'color',
                'label' => esc_html__('Link Color', 'advisom'),
            ),
            'inline_css' => array(
                'target' => array(
                    'nav#main-nav.main-nav > ul > li > a > span',
                ),
                'alter' => 'color',
            ),
        ),
        array(
            'id' => 'menu_link_color_hover',
            'transport' => 'postMessage',
            'control' => array(
                'type' => 'color',
                'label' => esc_html__('Link Color: Hover', 'advisom'),
            ),
            'inline_css' => array(
                'target' => array(
                    'nav#main-nav.main-nav > ul > li:hover > a > span',
                ),
                'alter' => 'color',
            ),
        ),
        array(
            'id' => 'submenu_background_color',
            'default' => '#fff',
            'control' => array(
                'type' => 'color',
                'label' => esc_html__('Submenu Background Color', 'advisom'),
            ),
            'inline_css' => array(
                'target' => '#main-nav .sub-menu' ,
                'alter' => 'background-color',
            ),
        ),
        array(
            'id' => 'submenu_margin_top',
            'default' => '100%',
            'control' => array(
                'type' => 'text',
                'label' => esc_html__('Submenu Margin ', 'advisom'),
                'description' => esc_html__('Example: 60%', 'advisom'),
            ),
            'inline_css' => array(
                'target' => '#main-nav .sub-menu' ,
                'alter' => 'top',
            ),
        ),
        array(
            'id' => 'submenu_link_hover_color',
            'default' => '#7e8288',
            'control' => array(
                'type' => 'color',
                'label' => esc_html__('Submenu Link Hover Text Color', 'advisom'),
            ),
            'inline_css' => array(
                'target' => '#main-nav .sub-menu li a:hover' ,
                'alter' => 'color',
            ),
        ),
    )
);

// Search & Cart
$this->sections['advisom_header_search_cart'] = array(
    'title' => esc_html__('Search & Cart', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        // Search Icon
        array(
            'id' => 'header_search_icon',
            'default' => false,
            'control' => array(
                'label' => esc_html__('Search Icon', 'advisom'),
                'type' => 'checkbox',
            ),
        ),
        // Cart Icon
        array(
            'id' => 'header_cart_icon',
            'default' => false,
            'control' => array(
                'label' => esc_html__('Cart Icon', 'advisom'),
                'type' => 'checkbox',
                'active_callback' => 'advisom_cac_has_woo',
            ),
        ),
    )
);

// Button
$this->sections['advisom_header_button'] = array(
    'title' => esc_html__('Button', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        array(
            'id' => 'header_button_text',
            'default' => '',
            'control' => array(
                'label' => esc_html__('Text', 'advisom'),
                'type' => 'text',
            ),
        ),
        array(
            'id' => 'header_button_url',
            'default' => '',
            'control' => array(
                'label' => esc_html__('Url', 'advisom'),
                'type' => 'text',
            ),
        ),
         // Margin Button
         array(
            'id' => 'header_button_margin',
            'default' => '100px',
            'control' => array(
                'type' => 'text',
                'label' => esc_html__('Header Button Margin', 'advisom'),
                'description' => esc_html__('Example: 44px', 'advisom'),
            ),
            'inline_css' => array(
                'target' => '.header-button',
                'alter' => 'margin-left',
            ),
        ),

    ),
);

// Header Info
$this->sections['advisom_header_info'] = array(
    'title' => esc_html__('Header Information', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        // Content
        array(
            'id' => 'header_info_phone_prefix',
            'default' => 'Phone:',
            'control' => array(
                'label' => esc_html__('Phone', 'advisom'),
                'type' => 'text',
                'rows' => 3,
            ),
        ),
        array(
            'id' => 'header_info_phone',
            'default' => '',
            'control' => array(
                'type' => 'text',
                'rows' => 3,
            ),
        ),
        array(
            'id' => 'header_info_email_prefix',
            'default' => 'Email:',
            'control' => array(
                'label' => esc_html__('Email', 'advisom'),
                'type' => 'text',
                'rows' => 3,
            ),
        ),
        array(
            'id' => 'header_info_email',
            'default' => '',
            'control' => array(
                'type' => 'text',
                'rows' => 3,
            ),
        ),
        array(
            'id' => 'header_info_address_prefix',
            'default' => 'Address:',
            'control' => array(
                'label' => esc_html__('Address', 'advisom'),
                'type' => 'text',
                'rows' => 3,
            ),
        ),
        array(
            'id' => 'header_info_address',
            'default' => '',
            'control' => array(
                'type' => 'text',
                'rows' => 3,
            ),
        ),
        // Style
        array(
            'id' => 'header_info_color',
            'default' => '',
            'control' => array(
                'label' => esc_html__('Header Infor Color', 'advisom'),
                'type' => 'color',
            ),
            'inline_css' => array(
                'target' => '.topbar-left .header-info .content, #header.header-dark .header-info .content',
                'alter' => 'color',
            ),
        ),
       // Font
        array(
            'id' => 'header_font',
            'default' => '600',
            'control' => array(
                'type' => 'text',
                'label' => esc_html__('Header Font', 'advisom'),
                'description' => esc_html__('Example: 600', 'advisom'),
            ),
            'inline_css' => array(
                'target' => '.header-info .content',
                'alter' => 'font-weight',
            ),

        ),
        // Margin Left
        array(
            'id' => 'header_margin_left',
            'default' => '44px',
            'control' => array(
                'type' => 'text',
                'label' => esc_html__('Header Margin Left', 'advisom'),
                'description' => esc_html__('Example: 44px', 'advisom'),
            ),
            'inline_css' => array(
                'target' => '.header-info .content',
                'alter' => 'margin-right',
            ),
        ),
        // Before icon color change
        array(
            'id' => 'header_icon_color',
            'default' => '',
            'control' => array(
                'label' => esc_html__('Header icon Color', 'advisom'),
                'type' => 'color',
            ),
            'inline_css' => array(
                'target' => '.topbar-left .header-info .content:before',
                'alter' => 'color',
            ),
        ),
    ),
);

// Top Bar Socials
$this->sections['advisom_header_socials'] = array(
    'title' => esc_html__('Social', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        array(
            'id' => 'header_socials',
            'default' => false,
            'control' => array(
                'label' => esc_html__('Enable', 'advisom'),
                'type' => 'checkbox',
            ),
        ),
        array(
            'id' => 'header_socials_spacing',
            'default' => '',
            'control' => array(
                'label' => esc_html__('Socials Spacing', 'advisom'),
                'description' => esc_html__('Gap Between Each Social. Example: 10px.', 'advisom'),
                'type' => 'text',
                'active_callback' => 'advisom_cac_has_header_socials',
            ),
        ),
    ),
);
// Top Bar
$this->sections['advisom_top_bar_checkbox'] = array(
    'title' => esc_html__('Top Bar', 'advisom'),
    'panel' => 'advisom_header',
    'settings' => array(
        // Search Icon
        array(
            'id' => 'header_top_bar',
            'default' => true,
            'control' => array(
                'label' => esc_html__('Show/Hide Top bar ', 'advisom'),
                'type' => 'checkbox',
            ),
        ),

    )
);


// Social settings
$social_options = advisom_header_social_options();
foreach ($social_options as $key => $val) {
    $this->sections['advisom_header_socials']['settings'][] = array(
        'id' => 'header_social_profiles[' . $key . ']',
        'control' => array(
            'label' => $val['label'],
            'type' => 'text',
            'active_callback' => 'advisom_cac_has_header_socials',
        ),
    );
}

// Remove var from memory
unset($social_options);