<?php
/**
 * Elementor Options
 *
 * @package advisom
 * @version 3.6.8
 */

namespace advisom\Settings;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Plugin;
use Elementor\Repeater;
use Elementor\Icons_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow as Group_Control_Box_Shadow;
use Elementor\Modules\DynamicTags\Module as TagsModule;

/** Advisom Settings Class For Elementor Options */
class Advisom_Settings {

	/** Advisom Settings Construct */
	public function __construct() {
		add_action( 'elementor/documents/register_controls', array( $this, 'advisom_register_settings' ), 10 );
	}

	/** Advisom Register Settings
	 *
	 * @param element $element storing Advisom Settings.
	 */
	public function advisom_register_settings( $element ) {
		$post_id   = $element->get_id();
		$post_type = get_post_type( $post_id );

		// $default = array();

		$this->advisom_general_settings( $element );

		if ( ( 'project' !== $post_type )
			&& ( 'post' !== $post_type )
			&& ( 'service' !== $post_type )
			&& ( 'pre_footer' !== $post_type ) ) {
				$this->advisom_page_settings( $element );
		}

		if ( is_singular( 'project' ) ) {
			$this->advisom_project_settings( $element );
		}

		if ( is_singular( 'post' ) ) {
			$this->advisom_post_settings( $element );
			// $this->advisom_update_post( $element);
		}

		if ( is_singular( 'pre_footer' ) ) {
			$this->advisom_prefooter_settings( $element );
		}
	}

	/** Advisom Register Settings
	 *
	 * @param element $element storing Advisom Settings.
	 */
	public function advisom_general_settings( $element ) {
		$element->start_controls_section(
			'advisom_general_settings',
			array(
				'label' => __( 'Page Settings', 'advisom' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$element->add_control(
			'layout',
			array(
				'label'     => __( 'Layout', 'advisom' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'after',
			)
		);

		$element->add_control(
			'site_layout_position',
			array(
				'label'   => __( 'Sidebar Position', 'advisom' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'sidebar-left'  => array(
						'title' => __( 'Sidebar Left', 'advisom' ),
						'icon'  => 'eicon-h-align-left',
					),
					'no-sidebar'    => array(
						'title' => __( 'No Sidebar', 'advisom' ),
						'icon'  => 'eicon-ban',
					),
					'sidebar-right' => array(
						'title' => __( 'Sidebar Right', 'advisom' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
			)
		);

		// Featured Title.
		$element->add_control(
			'featured_title_heading',
			array(
				'label'     => __( 'Featured Title', 'advisom' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'after',
			)
		);

		$element->add_control(
			'hide_featured_title',
			array(
				'label'     => __( 'Hide?', 'advisom' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'block',
				'options'   => array(
					'none'  => __( 'Yes', 'advisom' ),
					'block' => __( 'No', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} #featured-title' => 'display: {{VALUE}};',
				),
			)
		);

		$element->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'      => 'featured_title_bg',
				'label'     => __( 'Background', 'advisom' ),
				'types'     => array(
					'classic',
					'gradient',
					'video',
				),
				'selector'  => '{{WRAPPER}} #featured-title',
				'condition' => array(
					'hide_featured_title' => 'block',
				),
			)
		);

		$element->add_control(
			'custom_featured_title',
			array(
				'label'       => __( 'Custom Title', 'advisom' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'condition'   => array( 'hide_featured_title' => 'block' ),
			)
		);

		$element->add_control(
			'main_content_heading',
			array(
				'label'     => __( 'Main Content', 'advisom' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'after',
			)
		);

		$element->add_responsive_control(
			'content_padding',
			array(
				'label'              => __( 'Content Padding', 'advisom' ),
				'type'               => Controls_Manager::DIMENSIONS,
				'size_units'         => array( 'px' ),
				'allowed_dimensions' => array( 'top', 'bottom' ),
				'selectors'          => array(
					'{{WRAPPER}} #page #main-content' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
				),
			)
		);

		$element->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'     => 'main_content_bg',
				'label'    => __( 'Background', 'advisom' ),
				'types'    => array( 'classic', 'gradient', 'video' ),
				'selector' => '{{WRAPPER}} #main-content',
			)
		);

		$element->end_controls_section();
	}
	/** Advisom Register Settings
	 *
	 * @param element $element storing Advisom Settings.
	 */
	public function advisom_page_settings( $element ) {
		$elementor_templates = get_elementor_templates();
		// Header.
		$element->start_controls_section(
			'advisom_header_settings',
			array(
				'label' => __( 'Header', 'advisom' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$element->add_control(
			'header_heading',
			array(
				'label'     => __( 'Header', 'advisom' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'after',
			)
		);

		$element->add_control(
			'show_hide_elementor_header_template',
			array(
				'label'     => __( 'Show Elementor Template', 'advisom' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'none',
				'options'   => array(
					'block'  => __( 'Yes', 'advisom' ),
					'none' => __( 'No', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} .bzf-header-elementor' => 'display: {{VALUE}};',
				),
			)
		);

		$element->add_control(
			'show_hide_header_default_template',
			array(
				'label'     => __( 'Hide Default Template', 'advisom' ),
				'type'      => Controls_Manager::HIDDEN,
				'default'   => 'none',
				'options'   => array(
					'none'  => __( 'Yes', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} .bzf-header-template' => 'display: {{VALUE}};',
				),
				'condition' => array( 'show_hide_elementor_header_template' => 'block' ),
			)
		);

		$element->add_control(
			'show_hide_header_customizer_template',
			array(
				'label'     => __( 'Hide Elementor Customizer Template', 'advisom' ),
				'type'      => Controls_Manager::HIDDEN,
				'default'   => 'none',
				'options'   => array(
					'none'  => __( 'Yes', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} .bzf-custom-header-elementor' => 'display: {{VALUE}};',
				),
				'condition' => array( 'show_hide_elementor_header_template' => 'block' ),
			)
		);

		$element->add_control(
			'biz_elementor_header_template',
			array(
				'label'     => __( 'Elementor Templates', 'advisom' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'block',
				'options'   => $elementor_templates,
				'condition' => array( 'show_hide_elementor_header_template' => 'block' ),
			)
		);

		$element->add_control(
			'header_style',
			array(
				'label'       => __( 'Header Style', 'advisom' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '',
				'options'     => array(
					''                     => __( 'Default', 'advisom' ),
					'style-1'              => __( 'Basic', 'advisom' ),
					'style-1 header-float' => __( 'Basic - Float', 'advisom' ),
					'style-2'              => __( 'Full Width', 'advisom' ),
					'style-2 header-float' => __( 'Full Width - Float', 'advisom' ),
					'style-3'              => __( 'Modern', 'advisom' ),
					'style-4'              => __( 'Aside', 'advisom' ),
				),
				'description' => __( 'Update and refresh page to view change', 'advisom' ),
			)
		);

		// Logo.
		$element->add_control(
			'logo_heading',
			array(
				'label'     => __( 'Logo', 'advisom' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'after',
			)
		);

		$element->add_control(
			'custom_logo',
			array(
				'label' => __( 'Custom Logo', 'advisom' ),
				'type'  => Controls_Manager::MEDIA,
			)
		);

		$element->add_responsive_control(
			'logo_width',
			array(
				'label'      => __( 'Logo Width', 'advisom' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( 'px', '%' ),
				'range'      => array(
					'px' => array(
						'min' => 30,
						'max' => 500,
					),
					'%'  => array(
						'min' => 50,
						'max' => 150,
					),
				),
				'selectors'  => array(
					'{{WRAPPER}} #site-logo #site-logo-inner' => 'max-width: {{SIZE}}{{UNIT}} !important;',
				),
				50,
			)
		);

		$element->add_control(
			'header_extra',
			array(
				'label'       => __( 'Extra Classes', 'advisom' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
			)
		);

		$element->end_controls_section();

		// Footer.
		$element->start_controls_section(
			'advisom_footer_settings',
			array(
				'label' => __( 'Footer', 'advisom' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$element->add_control(
			'footer_heading',
			array(
				'label'     => __( 'Footer', 'advisom' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'after',
			)
		);
		$element->add_control(
			'show_hide_elementor_footer_template',
			array(
				'label'     => __( 'Show Elementor Template', 'advisom' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'none',
				'options'   => array(
					'block'  => __( 'Yes', 'advisom' ),
					'none' => __( 'No', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} .bzf-footer-elementor' => 'display: {{VALUE}};',
				),
			)
		);

		$element->add_control(
			'show_hide_footer_default_template',
			array(
				'label'     => __( 'Hide Default Template', 'advisom' ),
				'type'      => Controls_Manager::HIDDEN,
				'default'   => 'none',
				'options'   => array(
					'none'  => __( 'Yes', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} .bzf-footer-template' => 'display: {{VALUE}};',
				),
				'condition' => array( 'show_hide_elementor_footer_template' => 'block' ),
			)
		);

		$element->add_control(
			'show_hide_footer_customizer_template',
			array(
				'label'     => __( 'Hide Elementor Customizer Template', 'advisom' ),
				'type'      => Controls_Manager::HIDDEN,
				'default'   => 'none',
				'options'   => array(
					'none'  => __( 'Yes', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} .bzf-custom-footer-elementor' => 'display: {{VALUE}};',
				),
				'condition' => array( 'show_hide_elementor_footer_template' => 'block' ),
			)
		);

		$element->add_control(
			'biz_elementor_footer_template',
			array(
				'label'     => __( 'Elementor Templates', 'advisom' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'block',
				'options'   => $elementor_templates,
				'condition' => array( 'show_hide_elementor_footer_template' => 'block' ),
			)
		);
		$element->add_control(
			'hide_footer',
			array(
				'label'     => __( 'Hide?', 'advisom' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'block',
				'options'   => array(
					'none'  => __( 'Yes', 'advisom' ),
					'block' => __( 'No', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} #footer' => 'display: {{VALUE}};',
				),
			)
		);

		$element->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'      => 'footer_bg',
				'label'     => __( 'Background', 'advisom' ),
				'types'     => array( 'classic', 'gradient', 'video' ),
				'selector'  => '{{WRAPPER}} #footer',
				'condition' => array( 'hide_footer' => 'block' ),
			)
		);

		// Bottom.
		$element->add_control(
			'bottom_heading',
			array(
				'label'     => __( 'Bottom Bar', 'advisom' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'after',
			)
		);

		$element->add_control(
			'hide_bottom',
			array(
				'label'     => __( 'Hide?', 'advisom' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'block',
				'options'   => array(
					'none'  => __( 'Yes', 'advisom' ),
					'block' => __( 'No', 'advisom' ),
				),
				'selectors' => array(
					'{{WRAPPER}} #bottom' => 'display: {{VALUE}};',
				),
			)
		);

		$element->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'      => 'bottom_bg',
				'label'     => __( 'Background', 'advisom' ),
				'types'     => array(
					'classic',
					'gradient',
					'video',
				),
				'selector'  => '{{WRAPPER}} #bottom',
				'condition' => array( 'hide_bottom!' => 'none' ),
			)
		);

		$element->add_group_control(
			Group_Control_Border::get_type(),
			array(
				'name'           => 'bottom_border',
				'label'          => __( 'Border', 'advisom' ),
				'selector'       => '{{WRAPPER}} #bottom',
				'fields_options' => array(
					'border' => array(
						'default' => 'solid',
					),
					'width'  => array(
						'default' => array(
							'top'    => 1,
							'left'   => 0,
							'bottom' => 0,
							'right'  => 0,
						),
					),
				),
				'condition'      => array( 'hide_bottom!' => 'none' ),
			)
		);

		$element->end_controls_section();
	}

	/** Advisom Register Settings
	 *
	 * @param element $element storing Advisom Settings.
	 */
	public function advisom_project_settings( $element ) {
		$element->start_controls_section(
			'advisom_project_settings',
			array(
				'label' => __( 'Project Settings', 'advisom' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$element->add_control(
			'project_title',
			array(
				'label' => __( 'Custom Title', 'advisom' ),
				'type'  => Controls_Manager::TEXT,
			)
		);

		$element->add_control(
			'project_desc',
			array(
				'label' => __( 'Short Description', 'advisom' ),
				'type'  => Controls_Manager::WYSIWYG,
			)
		);

		$element->end_controls_section();
	}

	/** Advisom Register Settings
	 *
	 * @param element $element storing Advisom Settings.
	 */
	public function advisom_post_settings( $element ) {

		$element->start_controls_section(
			'advisom_post_settings',
			array(
				'label' => __( 'Post Settings', 'advisom' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$element->add_control(
			'video_url',
			array(
				'label'   => __( 'Video URL or Embeded Code', 'advisom' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '',
			)
		);

		$element->add_control(
			'gallery_images',
			array(
				'label'   => __( 'Add Images', 'advisom' ),
				'type'    => Controls_Manager::GALLERY,
				'default' => array(),
			)
		);

		$element->end_controls_section();
	}

	/** Advisom Register Settings
	 *
	 * @param element $element storing Advisom Settings.
	 */
	public function advisom_prefooter_settings( $element ) {
		$element->start_controls_section(
			'advisom_prefooter_settings',
			array(
				'label' => __( 'Pre-footer Settings', 'advisom' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$element->add_control(
			'pre_footer_heading',
			array(
				'label' => __( 'Show on page', 'advisom' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		$element->add_control(
			'pre_footer_blog',
			array(
				'label'        => __( 'Blog', 'advisom' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'On', 'advisom' ),
				'label_off'    => __( 'Off', 'advisom' ),
				'return_value' => 'yes',
				'default'      => '',
			)
		);

		$element->add_control(
			'pre_footer_single_post',
			array(
				'label'        => __( 'Blog Single', 'advisom' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'On', 'advisom' ),
				'label_off'    => __( 'Off', 'advisom' ),
				'return_value' => 'yes',
				'default'      => '',
			)
		);

		$element->add_control(
			'pre_footer_shop',
			array(
				'label'        => __( 'Shop', 'advisom' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'On', 'advisom' ),
				'label_off'    => __( 'Off', 'advisom' ),
				'return_value' => 'yes',
				'default'      => '',
			)
		);

		$element->add_control(
			'pre_footer_product',
			array(
				'label'        => __( 'Product', 'advisom' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'On', 'advisom' ),
				'label_off'    => __( 'Off', 'advisom' ),
				'return_value' => 'yes',
				'default'      => '',
			)
		);

		$element->add_control(
			'pre_footer_project_single',
			array(
				'label'        => __( 'Project Single', 'advisom' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'On', 'advisom' ),
				'label_off'    => __( 'Off', 'advisom' ),
				'return_value' => 'yes',
				'default'      => '',
			)
		);

		$element->end_controls_section();
	}
}

new Advisom_Settings();
