<?php
/**
 * Metabox Options
 *
 * @package advisom
 * @version 3.6.8
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/** Return the registered-widget array. */
function advisom_get_widget_registered() {
	global $wp_registered_sidebars;

	$widgets_areas = array();
	if ( ! empty( $wp_registered_sidebars ) ) {
		foreach ( $wp_registered_sidebars as $widget_area ) {
			$name = isset( $widget_area['name'] ) ? $widget_area['name'] : '';
			$id   = isset( $widget_area['id'] ) ? $widget_area['id'] : '';
			if ( $name && $id ) {
				$widgets_areas[ $id ] = $name;
			}
		}
	}

	return $widgets_areas;
}

/** Return the all-widget array */
function advisom_get_widget_mods() {
	$new_arr          = array();
	$widget_areas_mod = advisom_get_mod( 'widget_areas' );

	if ( is_array( $widget_areas_mod ) || is_object( $widget_areas_mod ) ) {
		foreach ( $widget_areas_mod as $key ) {
			$new_arr[ sanitize_key( $key ) ] = $key;
		}
	}

	$widget_areas = advisom_get_widget_registered() + $new_arr;

	return $widget_areas;
}

/** Get post meta, using rwmb_meta() function from Meta Box class
 *
 * @param key     $key value.
 * @param args    $args arguement array.
 * @param post_id $post_id get id.
 */
function advisom_metabox( $key, $args = array(), $post_id = null ) {
	if ( ! function_exists( 'rwmb_meta' ) ) {
		return false;
	}
	return rwmb_meta( $key, $args, $post_id );
}

/**  Registering meta boxes. Using Meta Box plugin: https://metabox.io/
 *
 * @param meta_boxes $meta_boxes to register.
 */
function advisom_register_meta_boxes( $meta_boxes ) {
	// Element Thumbnail.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Element Thumbnail', 'advisom' ),
		'id'     => 'opt-meta-box-element-thumbnail',
		'pages'  => array( 'post' ),
		'fields' => array(
			array(
				'name'             => esc_html__( 'Image', 'advisom' ),
				'id'               => 'element_thumbnail',
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
			),
		),
	);

	// Post Format Gallery.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Post Format: Gallery', 'advisom' ),
		'id'     => 'opt-meta-box-post-format-gallery',
		'pages'  => array( 'post' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Images', 'advisom' ),
				'id'   => 'gallery_images',
				'type' => 'image_advanced',
			),
		),
	);

	// Post Format Video.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Post Format: Video ( Embeded video from youtube, vimeo...)', 'advisom' ),
		'id'     => 'opt-meta-box-post-format-video',
		'pages'  => array( 'post' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Video URL or Embeded Code', 'advisom' ),
				'id'   => 'video_url',
				'type' => 'textarea',
			),
		),
	);

	// Short Description.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Short Description', 'advisom' ),
		'id'     => 'opt-meta-box-short-desc',
		'pages'  => array( 'post' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Short Description', 'advisom' ),
				'id'   => 'post-desc',
				'type' => 'textarea',
			),
		),
	);

	// Portfolio.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Project Settings', 'advisom' ),
		'id'     => 'opt-meta-box-project',
		'pages'  => array( 'project' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Custom Title', 'advisom' ),
				'id'   => 'title',
				'type' => 'textarea',
			),
			array(
				'name' => esc_html__( 'Short Description', 'advisom' ),
				'id'   => 'project_desc',
				'type' => 'textarea',
			),
		),
	);

	// Single Section.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Single Section Settings', 'advisom' ),
		'id'     => 'opt-meta-box-pages',
		'pages'  => array( 'section' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Show on Shop Page ?', 'advisom' ),
				'id'   => 'single_section_shop',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__( 'Show on Product Single Page ?', 'advisom' ),
				'id'   => 'single_section_shop_single',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__( 'Show on Single Post ?', 'advisom' ),
				'id'   => 'single_section_post',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__( 'Show on Single Project ?', 'advisom' ),
				'id'   => 'single_section_project',
				'type' => 'checkbox',
			),
		),
	);

	// Header Settings.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Header Settings', 'advisom' ),
		'id'     => 'opt-meta-box-header',
		'pages'  => array( 'page' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Custom Logo', 'advisom' ),
				'type' => 'single_image',
				'id'   => 'custom_header_logo',
			),
			array(
				'name' => esc_html__( 'Logo Width', 'advisom' ),
				'type' => 'text',
				'id'   => 'logo_width',
			),
			array(
				'name'    => esc_html__( 'Style', 'advisom' ),
				'id'      => 'header_style',
				'type'    => 'select',
				'options' => array(
					''        => esc_html__( 'Default', 'advisom' ),
					'style-1' => esc_html__( 'Basic', 'advisom' ),
					'style-2' => esc_html__( 'Modern', 'advisom' ),
				),
				'std'     => '',
			),
			array(
				'name'          => esc_html__( 'Background', 'advisom' ),
				'id'            => 'header_background',
				'type'          => 'color',
				'alpha_channel' => true,
				'js_options'    => array(
					'palettes' => array( '#000000', '#ffffff', '#000080', '#0fc392', '#f37a32', '#bb5bd6', '#32b1f3', '#f87055' ),
				),
			),
			array(
				'type' => 'text',
				'name' => esc_html__( 'Header Extra Class', 'advisom' ),
				'id'   => 'header_extra',
			),
			array(
				'type' => 'text',
				'name' => esc_html__( 'Button Extra Class', 'advisom' ),
				'id'   => 'header_button_extra',
			),
		),
	);

	// Featured Title Settings.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Featured Title Settings', 'advisom' ),
		'id'     => 'opt-meta-box-featured-title',
		'pages'  => array( 'page' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Hide?', 'advisom' ),
				'id'   => 'hide_featured_title',
				'type' => 'checkbox',
			),
			array(
				'type'             => 'image_advanced',
				'name'             => esc_html__( 'Background', 'advisom' ),
				'id'               => 'featured_title_bg',
				'max_file_uploads' => 1,
			),
			array(
				'type' => 'text',
				'name' => esc_html__( 'Custom Title', 'advisom' ),
				'id'   => 'custom_featured_title',
			),
		),
	);

	// Main Content Settings.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Main Content Settings', 'advisom' ),
		'id'     => 'opt-meta-box-main-content',
		'pages'  => array( 'page' ),
		'fields' => array(
			array(
				'name'    => esc_html__( 'Layout Position', 'advisom' ),
				'id'      => 'page_layout',
				'type'    => 'image_select',
				'options' => array(
					'no-sidebar'    => get_template_directory_uri() . '/assets/admin/img/full-content.png',
					'sidebar-left'  => get_template_directory_uri() . '/assets/admin/img/sidebar-left.png',
					'sidebar-right' => get_template_directory_uri() . '/assets/admin/img/sidebar-right.png',
				),
				'std'     => 'no-sidebar',
			),
			array(
				'name'    => esc_html__( 'Sidebar', 'advisom' ),
				'id'      => 'page_sidebar',
				'type'    => 'select',
				'options' => advisom_get_widget_mods(),
				'std'     => 'sidebar-page',
				'desc'    => esc_html__( 'This option do not apply if Layout Position is full-width.', 'advisom' ),
			),
			array(
				'name'          => 'Background Color',
				'id'            => 'main_content_bg',
				'type'          => 'color',
				'alpha_channel' => true,
			),
			array(
				'type'             => 'image_advanced',
				'name'             => esc_html__( 'Background Image', 'advisom' ),
				'id'               => 'main_content_bg_img',
				'max_file_uploads' => 1,
			),
			array(
				'name' => esc_html__( 'Remove: Top & Bottom Padding?', 'advisom' ),
				'id'   => 'hide_padding_content',
				'type' => 'checkbox',
			),
		),
	);

	// Footer Settings.
	$meta_boxes[] = array(
		'title'  => esc_html__( 'Footer Settings', 'advisom' ),
		'id'     => 'opt-meta-box-footer',
		'pages'  => array( 'page' ),
		'fields' => array(
			array(
				'name' => esc_html__( 'Hide: Footer?', 'advisom' ),
				'id'   => 'hide_footer',
				'type' => 'checkbox',
			),
			array(
				'name'          => 'Footer Widget: Background',
				'id'            => 'footer_bg',
				'type'          => 'color',
				'alpha_channel' => true,
			),
			array(
				'type'             => 'image_advanced',
				'name'             => esc_html__( 'Footer Widget: Image Background', 'advisom' ),
				'id'               => 'footer_bg_img',
				'max_file_uploads' => 1,
			),
			array(
				'type' => 'text',
				'name' => esc_html__( 'Footer Class', 'advisom' ),
				'id'   => 'footer_class',
			),
			array(
				'name'    => esc_html__( 'Bottom Style', 'advisom' ),
				'id'      => 'bottom_bar_style',
				'type'    => 'select',
				'options' => array(
					''        => esc_html__( 'Default', 'advisom' ),
					'style-1' => esc_html__( 'Only Copyright', 'advisom' ),
					'style-2' => esc_html__( 'Logo + Copyright', 'advisom' ),
				),
				'std'     => '',
			),
			array(
				'name'          => 'Bottom Bar: Background',
				'id'            => 'bottom_bg',
				'type'          => 'color',
				'alpha_channel' => true,
			),
			array(
				'type' => 'text',
				'name' => esc_html__( 'Bottom Class', 'advisom' ),
				'id'   => 'bottom_class',
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'advisom_register_meta_boxes' );
