<?php
/**
 * Advisom Theme Hooks.
 *
 * @package advisom
 * @version 3.6.8
 */

/** Custom classes to body tag. */
function advisom_body_classes() {
	$classes[] = '';

	if ( class_exists( '\Elementor\Plugin' ) ) {
		if ( \Elementor\Plugin::$instance->preview->is_preview_mode() ) {
			$classes[] = 'elementor-preview';
		}
	}

	if ( get_post_type() === 'elementor_library' ) {
		$classes[] = 'elementor-template';
	}

	if ( is_page() && advisom_metabox( 'header_background' ) ) {
		$classes[] = 'header-has-custom-bg';
	}

	// Header fixed.
	if ( advisom_get_mod( 'header_fixed', false ) ) {
		$classes[] = 'header-fixed';
	}

	// Get layout position.
	$classes[]       = advisom_layout_position();
	$layout_position = advisom_layout_position();

	if ( ! is_page() && 'no-sidebar' !== $layout_position && ! is_active_sidebar( 'sidebar-blog' ) ) {
		$classes[] = 'blog-empty-widget';
	}

	if ( is_page() && 'no-sidebar' !== $layout_position && ! is_active_sidebar( 'sidebar-page' ) ) {
		$classes[] = 'page-empty-widget';
	}

	// Get layout style.
	$layout_style = advisom_get_mod( 'site_layout_style', 'full-width' );
	$classes[]    = 'site-layout-' . $layout_style;

	// Get header style.
	$header_style = advisom_get_mod( 'header_site_style', 'style-1' );

	if ( is_page() && advisom_metabox( 'header_style' ) ) {
		$header_style = advisom_metabox( 'header_style' );
	}

	if ( is_page() && advisom_elementor( 'header_style' ) ) {
		$header_style = advisom_elementor( 'header_style' );
	}

	$classes[] = 'header-' . $header_style;

	if ( is_page() ) {
		$classes[] = 'is-page';
	}

	if ( is_page_template( 'templates/page-onepage.php' ) ) {
		$classes[] = 'one-page';
	}

	if ( ( is_page() && advisom_metabox( 'hide_padding_content' ) )
		|| ( is_singular( 'project' ) && advisom_metabox( 'hide_padding_content' ) ) ) {
			$classes[] = 'no-padding-content';
	}

	// Add classes for Woo pages.
	if ( advisom_is_woocommerce_page() ) {
		$classes[] = 'woocommerce-page';
	}

	if ( advisom_is_woocommerce_shop() ) {
		$classes[] = 'main-shop-page';
	}

	if ( advisom_is_woocommerce_shop() || advisom_is_woocommerce_archive_product() ) {
		$shop_cols = advisom_get_mod( 'shop_columns', '3' );
		$classes[] = 'shop-col-' . $shop_cols;
	}

	// Add class for search page.
	if ( is_search() ) {
		$classes[] = 'search-page';
	}

	// Boxed Layout dropshadow.
	if ( 'boxed' === $layout_style && advisom_get_mod( 'site_layout_boxed_shadow' ) ) {
		$classes[] = 'box-shadow';
	}

	if ( advisom_get_mod( 'header_search_icon' ) ) {
		$classes[] = 'header-simple-search';
	}

	if ( is_singular( 'post' ) ) {
		$classes[] = 'is-single-post';
	}

	if ( is_singular( 'project' ) ) {
		$classes[] = 'page-single-project';
	}

	if ( advisom_get_mod( 'advisom_blog_single_related', false ) ) {
		$classes[] = 'has-related-post';
	}

	if ( advisom_get_mod( 'project_related', false ) ) {
		$classes[] = 'has-related-project';
	}

	if ( ! is_active_sidebar( 'sidebar-footer-1' ) &&
		! is_active_sidebar( 'sidebar-footer-2' ) &&
		! is_active_sidebar( 'sidebar-footer-3' ) &&
		! is_active_sidebar( 'sidebar-footer-4' ) &&
		! is_active_sidebar( 'sidebar-footer-5' ) ) {
			$classes[] = 'footer-no-widget';
	}

	// Footer Style.
	if ( advisom_is_woocommerce_shop() && advisom_get_mod( 'shop_footer_style' ) ) {
		$classes[] = 'footer-' . advisom_get_mod( 'shop_footer_style' );
	} elseif ( is_singular( 'product' ) && advisom_get_mod( 'shop_single_footer_style', false ) ) {
		$classes[] = 'footer-' . advisom_get_mod( 'shop_single_footer_style' );
	} else {
		if ( advisom_metabox( 'footer_style' ) ) {
			$classes[] = 'footer-' . advisom_metabox( 'footer_style' );
		} else {
			$classes[] = 'footer-' . advisom_get_mod( 'footer_style' );
		}
	}

	// Return classes.
	return $classes;
}
add_filter( 'body_class', 'advisom_body_classes' );

/** Remove products and pages results from the search form widget
 *
 * @param query $query for custom search.
 */
function advisom_custom_search_query( $query ) {

	if ( is_admin() || ! $query->is_main_query() ) {
		return;
	}

	if ( isset( $_GET['post_type'] ) && ( 'product' === $_GET['post_type'] ) ) {
		return;
	}

	if ( $query->is_search() ) {
		$in_search_post_types = get_post_types( array( 'exclude_from_search' => false ) );

		$post_types_to_remove = array( 'product' );

		foreach ( $post_types_to_remove as $post_type_to_remove ) {
			if ( is_array( $in_search_post_types )
				&& in_array( $post_type_to_remove, $in_search_post_types )
			) {
				unset( $in_search_post_types[ $post_type_to_remove ] );
				$query->set( 'post_type', $in_search_post_types );
			}
		}
	}
}
add_action( 'pre_get_posts', 'advisom_custom_search_query' );

/** Update Woocommerce Cart.
 *
 * @param fragments $fragments for woocommerce.
 */
function advisom_woocommerce_header_add_to_cart_fragment( $fragments ) {
	ob_start();

	if ( class_exists( 'woocommerce' ) ) : ?>
		<a class="cart-info" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php echo esc_attr__( 'View your shopping cart', 'advisom' ); ?>"><?php echo esc_html( advisom_svg( 'cart' ) ); ?><?php /* translators: %s: search term */ echo esc_html( sprintf( _n( '%d item', '%d items', WC()->cart->cart_contents_count, 'advisom' ), WC()->cart->cart_contents_count ) ); ?> <?php echo esc_html( WC()->cart->get_cart_total() ); ?></a>
		<?php
	endif;

	$fragments['a.cart-info'] = ob_get_clean();

	return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'advisom_woocommerce_header_add_to_cart_fragment' );

/** Sets the content width in pixels, based on the theme's design and stylesheet. */
function advisom_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'advisom_content_width', 1140 );
}
add_action( 'after_setup_theme', 'advisom_content_width', 0 );

/**
 * Modifies tag cloud widget arguments to have all tags in the widget same font size.
 *
 * @param arguements $args for widgets.
 */
function advisom_widget_tag_cloud_args( $args ) {
	$args['largest']  = 14;
	$args['smallest'] = 14;
	$args['unit']     = 'px';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'advisom_widget_tag_cloud_args' );

/**
 * Change default read more style
 *
 * @param more $more for excerpt.
 */
function advisom_excerpt_more( $more ) {
	return '';
}
add_filter( 'excerpt_more', 'advisom_excerpt_more', 10 );

/** Custom excerpt length for posts */
function advisom_content_length() {
	$length = advisom_get_mod( 'blog_excerpt_length', '50' );
	$length = intval( $length );

	if ( ! empty( $length ) || 0 !== $length ) {
		return $length;
	}
}
add_filter( 'excerpt_length', 'advisom_content_length', 999 );

/** Prevent page scroll when clicking the more link
 *
 * @param link $link for scroll.
 */
function advisom_remove_more_link_scroll( $link ) {
	$link = preg_replace( '|#more-[0-9]+|', '', $link );

	return $link;
}
add_filter( 'the_content_more_link', 'advisom_remove_more_link_scroll' );

/** Remove read-more link so we can custom it  */
function advisom_remove_read_more_link() {
	return '';
}
add_filter( 'the_content_more_link', 'advisom_remove_read_more_link' );

/**
 * Custom html categories widget
 *
 * @param link $link for scroll.
 */
function cat_count_span( $link ) {
	$link = str_replace( '</a> (', '</a> <span>', $link );
	$link = str_replace( ')', '</span>', $link );
	return $link;
}
add_filter( 'wp_list_categories', 'cat_count_span' );

/**
 * Column of related product
 *
 * @param arguements $args for related products.
 */
function advisom_related_products_args( $args ) {
	$column                 = advisom_get_mod( 'shop_realted_columns', 3 );
	$args['posts_per_page'] = $column;
	$args['columns']        = $column;
	return $args;
}

add_filter( 'woocommerce_output_related_products_args', 'advisom_related_products_args', 20 );
