<?php
/**
 * Featured Title
 *
 * @package advisom
 * @version 3.6.8
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Exit if disabled via Customizer or Metabox .
if ( ! advisom_get_mod( 'featured_title', true )
	|| ( is_page() && advisom_metabox( 'hide_featured_title' ) ) ) {
	return;
}

// Output class based on style.

$cls = 'clearfix';

$style = advisom_get_mod( 'featured_title_style', 'simple' );

if ( $style ) {
	$cls .= ' ' . $style;
}

// Get default title for all pages.

$advisom_title = advisom_get_mod( 'blog_featured_title', 'Our Blog' );

// Override title for specify pages.

if ( is_singular() ) {

	$advisom_title = get_the_title();

} elseif ( is_search() ) {
	/* translators: %s: search term */
	$advisom_title = sprintf( esc_html__( 'Search results for &quot;%s&quot;', 'advisom' ), get_search_query() );

} elseif ( is_404() ) {

	$advisom_title = esc_html__( 'Not Found', 'advisom' );

} elseif ( is_author() ) {

	the_post();

	/* translators: %s: search term */
	$advisom_title = sprintf( esc_html__( 'Author Archives: %s', 'advisom' ), get_the_author() );

	rewind_posts();

} elseif ( is_day() ) {

	/* translators: %s: search term */
	$advisom_title = sprintf( esc_html__( 'Daily Archives: %s', 'advisom' ), get_the_date() );

} elseif ( is_month() ) {

	/* translators: %s: search term */
	$advisom_title = sprintf( esc_html__( 'Monthly Archives: %s', 'advisom' ), get_the_date( 'F Y' ) );

} elseif ( is_year() ) {

	/* translators: %s: search term */
	$advisom_title = sprintf( esc_html__( 'Yearly Archives: %s', 'advisom' ), get_the_date( 'Y' ) );

} elseif ( is_tax() || is_category() || is_tag() ) {

	$advisom_title = single_term_title( '', false );

}



// If the page has custom title.

if ( is_page() && advisom_metabox( 'custom_featured_title' ) ) {

	$advisom_title = advisom_metabox( 'custom_featured_title' );

}

// For shop page.

if ( advisom_is_woocommerce_shop() ) {

	$advisom_title = advisom_get_mod( 'shop_featured_title', 'Our Shop' );

}

// For single shop page.

if ( is_singular( 'product' ) ) {

	$sst = advisom_get_mod( 'shop_single_featured_title', 'Our Shop' );

	if ( '' !== $sst ) {
		$advisom_title = $sst;
	} else {
		$advisom_title = get_the_title();
	}
}

// For single post.

if ( is_singular( 'post' ) ) {

	$advisom_title = advisom_get_mod( 'blog_single_featured_title', 'Our Blog' );

	if ( ! $advisom_title ) {
		$advisom_title = get_the_title();
	}
} ?>



<div id="featured-title" class="<?php echo esc_attr( $cls ); ?>" style="<?php echo esc_html( advisom_featured_title_bg() ); ?>">
<?php if ( advisom_get_mod( 'featured_title_check_color', true ) ) : ?>
<div class="featured-title-overlay" ></div>
<?php endif; ?>
	<div class="advisom_container clearfix">

		<div class="inner-wrap">

			<?php if ( advisom_get_mod( 'featured_title_heading', true ) ) : ?>

				<div class="title-group">

					<h1 class="main-title">

						<?php echo do_shortcode( $advisom_title ); ?>

					</h1>

				</div>

			<?php endif; ?>



			<?php if ( advisom_get_mod( 'featured_title_breadcrumbs', true ) ) : ?>

				<div id="breadcrumbs">

					<div class="breadcrumbs-inner">

						<div class="breadcrumb-trail">

							<?php advisom_breadcrumbs(); ?>

						</div>

					</div>

				</div>

			<?php endif; ?>

		</div>

	</div>

</div><!-- /#featured-title -->



